@@ -1,5 +1,5 @@
-//! # FFI opaque pointers.
-//! 
+//! FFI opaque pointers.
+//!
 //! FFI to use Rust objects from C as opaque pointer.
 
 #![allow(unsafe_code)]
@@ -7,10 +7,8 @@
 #![warn(clippy::pedantic)]
 #![deny(clippy::complexity)]
 #![deny(clippy::cognitive_complexity)]
-#![allow(clippy::needless_return)] // To avoid surprise in devs more familiar where return is always explicit
-
+#![allow(clippy::needless_return)] // To avoid surprise in devs more familiar with languages where return is always explicit
 #![doc(html_no_source)]
-
 #![no_std]
 
 #[cfg(all(feature = "alloc", not(feature = "std")))]
@@ -26,17 +24,19 @@ use std::boxed::Box;
 #[cfg(all(feature = "std", feature = "c-types"))]
 pub mod c;
 
-#[cfg(any(feature = "panic-if-null", debug_assertions))]
+pub mod error;
+
 #[inline]
-fn panic_if_null<T>(pointer: *const T) {
+fn null_error_check<T>(pointer: *const T) -> Result<(), crate::error::PointerError> {
     if pointer.is_null() {
-        log::error!("Trying to use a NULL pointer as a opaque pointer to Rust data");
-        unreachable!("Trying to use a NULL pointer as a opaque pointer to Rust data");
+        log::error!("Using a NULL pointer as an opaque pointer to Rust's data");
+        return Err(crate::error::PointerError::NulPointer);
     }
+    return Ok(());
 }
 
 /// Get a heap-allocated raw pointer without ownership.
-/// 
+///
 /// To back to manage the memory with ownership use [`own_back<T>()`].
 #[cfg(any(feature = "alloc", feature = "std"))]
 #[inline]
@@ -44,63 +44,73 @@ pub fn raw<T>(data: T) -> *mut T {
     return Box::into_raw(Box::new(data));
 }
 
-#[deprecated(
-    since = "0.7.2",
-    note = "Use `own_back<T>()` instead"
-)]
-#[allow(missing_docs)]
+#[deprecated(since = "0.7.2", note = "Use `own_back<T>()` instead")]
 #[cfg(any(feature = "alloc", feature = "std"))]
 #[inline]
+/// Call to `own_back<T>(pointer: *mut T)` ignoring the result.
+///
+/// This ignore null pointers without an error.
+///
+/// # Safety
+///
+/// Invalid pointer or call it twice could cause an undefined behavior or heap error and a crash.
 pub unsafe fn free<T>(pointer: *mut T) {
-    own_back(pointer);
+    let _ = own_back(pointer); // Ignore the must use lint as previous behavior was ignore null pointers
 }
 
 /// Opposite of [`raw<T>()`], to use Rust's ownership as usually.
-/// 
+///
+/// # Errors
+///
+/// The pointer must be not null as it is an obvious invalid pointer.
+///
 /// # Safety
-/// 
-/// The pointer must be a valid reference and never call it twice or behavior is undefined.
-/// 
-/// That could produce a HEAP error that produce a crash.
+///
+/// Invalid pointer or call it twice could cause an undefined behavior or heap error and a crash.
 #[doc(alias = "free")]
 #[cfg(any(feature = "alloc", feature = "std"))]
 #[inline]
-pub unsafe fn own_back<T>(pointer: *mut T) -> T {
-    #[cfg(any(feature = "panic-if-null", debug_assertions))]
-    panic_if_null(pointer);
+pub unsafe fn own_back<T>(pointer: *mut T) -> Result<T, crate::error::PointerError> {
+    null_error_check(pointer)?;
     // CAUTION: this is the unsafe part of the function.
     let boxed = Box::from_raw(pointer);
-    return *boxed;
+    return Ok(*boxed);
 }
 
 /// Reference to a object but without back to own it.
-/// 
+///
 /// That's the difference with [`own_back<T>()`], you must
 /// use [`own_back<T>()`] to own it again and it will be dropped.
-/// 
+///
+/// # Errors
+///
+/// The pointer must be not null as it is an obvious invalid pointer.
+///
 /// # Safety
-/// 
+///
 /// Invalid pointer or call it twice could cause an undefined behavior or heap error and a crash.
 #[inline]
-pub unsafe fn object<'a, T>(pointer: *const T) -> &'a T {
-    #[cfg(any(feature = "panic-if-null", debug_assertions))]
-    panic_if_null(pointer);
+pub unsafe fn object<'a, T>(pointer: *const T) -> Result<&'a T, crate::error::PointerError> {
+    null_error_check(pointer)?;
     // CAUTION: this is unsafe
-    return &*pointer;
+    return Ok(&*pointer);
 }
 
 /// Mutable reference to a object but without back to own it.
-/// 
+///
 /// That's the difference with [`own_back<T>()`], you must
 /// use [`own_back<T>()`] to own it again and it will be dropped.
-/// 
+///
+/// # Errors
+///
+/// The pointer must be not null as it is an obvious invalid pointer.
+///
 /// # Safety
-/// 
+///
 /// Invalid pointer or call it twice could cause an undefined behavior or heap error and a crash.
 #[inline]
-pub unsafe fn mut_object<'a, T>(pointer: *mut T) -> &'a mut T {
-    #[cfg(any(feature = "panic-if-null", debug_assertions))]
-    panic_if_null(pointer);
+pub unsafe fn mut_object<'a, T>(pointer: *mut T) -> Result<&'a mut T, crate::error::PointerError> {
+    null_error_check(pointer)?;
     // CAUTION: this is unsafe
-    return &mut *pointer;
+    return Ok(&mut *pointer);
 }
